@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2009 Index Data
+ * Copyright (C) 1995-2010 Index Data
  * See the file LICENSE for details.
  */
 /**
@@ -27,7 +27,7 @@ NMEM odr_extract_mem(ODR o)
     return r;
 }
 
-void *odr_malloc(ODR o, int size)
+void *odr_malloc(ODR o, size_t size)
 {
     return nmem_malloc(o->mem, size);
 }
@@ -57,7 +57,7 @@ Odr_bool *odr_booldup(ODR o, Odr_bool v)
     return nmem_booldup(o->mem, v);
 }
 
-int odr_total(ODR o)
+size_t odr_total(ODR o)
 {
     return nmem_total(o->mem);
 }
@@ -124,6 +124,27 @@ int odr_seek(ODR o, int whence, int offset)
     o->pos = offset;
     return 0;
 }
+
+Odr_int odr_strtol(const char *nptr, char **endptr, int base)
+{
+#if NMEM_64
+#if WIN32
+    return _strtoui64(nptr, endptr, base);
+#else
+    return strtoll(nptr, endptr, base);
+#endif
+
+#else
+    return strtol(nptr, endptr, base);
+#endif
+}
+
+Odr_int odr_atoi(const char *s)
+{
+    char *endptr;
+    return odr_strtol(s, &endptr, 10);
+}
+
 /*
  * Local variables:
  * c-basic-offset: 4
